#!/bin/sh
# *************************************************************************
#
# Licensed Materials - Property of IBM
#
# 5724-CYN
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *************************************************************************
# @(#)49   1.7   ppe.probe/src/bin/cyn_os400_collector.sh, am_ppe.probe, itcam6 9/9/05 04:53:27
# *************************************************************************

# The DC installer sets this variable to the DC runtime path
PROD_HOME=@{AM_HOME}

# The DC installer sets this variable to the Tivoli common directory path
COMDIR=@{TIVOLI_COMMON_DIR}

SCRIPT=`basename $0`

print_help()
{
  cat << EOF

	$SCRIPT		Version 06.00.00


This program is intended to collect diagnostic information from the
computer upon which it is executed. Collected data includes:
	- system configuration;
	- environment;
	- disk space information;
	- network state;
	- software revision;
	- Data Collector configuration and log files.


Command line syntax is:

	$SCRIPT

EOF

  exit 0
}

report_error()
{
  exec 1>&2
  echo
  echo Error: $1
  echo
  exit 1
}

if [ -n "$1" ]; then
  if [ "$1" = "-help" ]; then
    print_help
  else
    report_error "unknown option  $1"
  fi
fi

PATH="/usr/bin:/usr/sbin:$PATH"
export PATH

TmpDir=$HOME/tmp/CYN
DestName=`hostname`-CYNenv
DigDir=$TmpDir/$DestName

rm -Rf $DigDir $DigDir.tar* 2>/dev/null
mkdir -p $DigDir || exit 1

echo "Data Collector runtime located in $PROD_HOME"
cd $PROD_HOME || exit 1

DigInfo=$DigDir/system.info
OSVersion=`uname -r`
OSType=`uname -s`
OSArch=`uname -m`


cat > $DigInfo << EOF
OS type     : $OSType
OS version  : $OSVersion
OS Arch     : $OSArch

User        : `logname 2>&1`
Host name   : `hostname 2>&1`
Date        : `date 2>&1`
Runtime     : $PROD_HOME

==> uname:
`uname -a 2>&1`

==> ulimit:
`ulimit -a 2>&1`
EOF

echo >> $DigInfo

echo "...Collecting environment information"
ls -laRL $PROD_HOME >> $DigDir/dir.info
env > $DigDir/env.info 2>&1

echo "...Collecting system status"
system "wrksyssts" > $DigDir/syssts.info 2>&1

echo "...Collecting software revision information"
system "DSPSFWRSC" > $DigDir/rev.info 2>&1
 

echo "...Collecting log files"
#cp -Rf logs $DigDir/
[ -r /tmp/db2setup.log ] && cp -f /tmp/db2setup.log $DigDir/

for DNAME in BWM CYN; do
  if [ -d $COMDIR/$DNAME ]; then
    mkdir -p $DigDir/common/$DNAME 2>/dev/null
    for PNAME in logs FFDC; do
      cp -Rf $COMDIR/$DNAME/$PNAME $DigDir/common/$DNAME/ 2>/dev/null
    done
  fi
done

echo "...Collecting configuration files"
cp -Rf etc $DigDir/

echo "...Packing collected information"
cd $TmpDir || exit 1
/qopensys/usr/bin/tar -cf $DestName.tar $DestName 2>&1
rm -Rf $DestName

echo "
********************************************************************
$DigDir.tar
This file has been created and contains diagnostic information.
Forward this binary file to your IBM Support representative.
********************************************************************
"
